# PDF TO TEXT CONVERTER
A simple Python script to convert PDF Documents to Text Files.

Supported Operating Systems:-

* Debian / Debian Based Linux Distros
* Ubuntu / Ubuntu Based Linux Distros
* Fedora / Fedora Based Linux Distros
* Windows 10 and above Windows Operating Systems.

It converts all PDF Files in current working Folder/Directory to 
Text Files.

NOTE: THIS TOOL IS MEANT TO CONVERT THOSE PDF DOCUMENTS WHICH ARE NOT EASILY CONVERTBLE TO OTHER FORMATS.
CURRENTLY THIS TOOL SUPPORTS ENGLISH ONLY.

